<?php
/**
 * Installments helper class
 *
 * @package WooAsaas
 */

namespace WC_Asaas\Helper;

/**
 * Installment calculation helper functions
 */
class Installments_Helper {

	/**
	 * Get the installment list with the number of installments and the value
	 * for each ones
	 *
	 * @param float $total The total to be calculated.
	 * @param int   $max_installments The number maximum of installments.
	 * @param float $min_installment_value The minimum value of an installment.
	 * @return number[int] The list with the intallment count (key) and the
	 *                     value of each installment (value).
	 */
	public function get_installment_list( $total, $max_installments, $min_installment_value = false ) {
		$intalments_qty = $max_installments;
		if ( false !== $min_installment_value ) {
			$intalments_qty = $this->calculate_max_installment_qty( $total, $max_installments, $min_installment_value );
		}

		$installments_list = array();
		for ( $i = 1; $i <= $intalments_qty; $i++ ) {
			$installments_list[ $i ] = $this->calculate_installment( $total, $i );
		}

		return $installments_list;
	}

	/**
	 * Calculate if the mininimum value of an installment reduce the quantity
	 * of installments
	 *
	 * @param float $total The total to be calculated.
	 * @param int   $max_installments The number maximum of installments.
	 * @param float $min_installment_value The minimum value of an installment.
	 * @return float The maximum possible installments for the total.
	 */
	public function calculate_max_installment_qty( $total, $max_installments, $min_installment_value ) {
		if ( 0 === $min_installment_value ) {
			return $max_installments;
		}

		return min( floor( $total / $min_installment_value ), $max_installments );
	}

	/**
	 * Calculate the installment value
	 *
	 * @param float $total The total to be calculated.
	 * @param int   $intalments_qty The number of installments.
	 * @return number The value of each installment.
	 */
	public function calculate_installment( $total, $intalments_qty ) {
		return $total / $intalments_qty;
	}
}
